==> liblxqt_0.14.1.1+rb2.orig.tar.xz: liblxqt-0.14.1.1+rb2/translations/liblxqt_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialóg</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="74"/>
        <source>LXQt Power Manager Error</source>
        <translation>Chyba správcu napájania LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="74"/>
        <source>Hibernate failed.</source>
        <translation>Hibernácia sa nepodarila.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="154"/>
        <source>Notifications Fallback</source>
        <translation>Náhradné oznámenia</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="117"/>
        <source>Hibernate</source>
        <translation>Hibernovať</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="124"/>
        <source>Suspend</source>
        <translation>Úsporný režim</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="131"/>
        <source>Reboot</source>
        <translation>Reštartovať</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="138"/>
        <source>Shutdown</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="145"/>
        <source>Logout</source>
        <translation>Odhlásiť sa</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="157"/>
        <source>LXQt Session Suspend</source>
        <translation>Úsporný režim relácie LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Skutočne chcete svoj počítač uviesť do úsporného režimu?&lt;p&gt;Uvedie počítač do stavu s nízkym odberom prúdu. Stav systému sa pri strate napájania nezachová.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="167"/>
        <source>LXQt Session Hibernate</source>
        <translation>Hibernácia relácie LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Skutočne chcete svoj počítač hibernovať?&lt;p&gt;Uvedie počítač do stavu s nízkym odberom prúdu. Stav systému sa pri strate napájania zachová.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="177"/>
        <source>LXQt Session Reboot</source>
        <translation>Reštart relácie LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Skutočne chcete svoj počítač reštartovať? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="187"/>
        <source>LXQt Session Shutdown</source>
        <translation>Vypnutie relácie LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Skutočne chcete svoj počítač vypnúť? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <source>LXQt Session Logout</source>
        <translation>Odhlásenie relácie LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="198"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Skutočne sa chcete odhlásiť z vášho počítača? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="206"/>
        <location filename="../lxqtpowermanager.cpp" line="211"/>
        <source>LXQt Power Manager Error</source>
        <translation>Chyba správcu napájania LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="206"/>
        <source>Hibernate failed.</source>
        <translation>Hibernácia sa nepodarila.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="211"/>
        <source>Suspend failed.</source>
        <translation>Uvedenie do úsporného režimu sa nepodarilo.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="236"/>
        <source>Lock Screen</source>
        <translation>Zamknúť obrazovku</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Chyba šetriča obrazovky</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="162"/>
        <location filename="../lxqtscreensaver.cpp" line="168"/>
        <location filename="../lxqtscreensaver.cpp" line="175"/>
        <source>Screen Saver Activation Error</source>
        <translation>CHyba pri aktivácii šetriča obrazovky</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="176"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>Počas spúšťania šetriča obrazovky sa stala chyba - nezdokumentovaná návratová hodnota z xdg-screensaver: %1.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="157"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. Chyba syntaxe v argumentoch xdg-screensaver.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="163"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. Uistite sa, či je xdg-screensaver nainštalovaný a spustený.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="169"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Pri štarte šetriča obrazovky sa vyskytla chyba. Operácia „activate“ zlyhala. Uistite sa, či je xdg-screensaver nainštalovaný a spustený.</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation>Vyberte si stránku na zobrazenie.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Chyba správcu napájania</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface je nepoužiteľné</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Chyba správcu napájania (volanie D-Bus)</translation>
    </message>
</context>
</TS>

==> liblxqt_0.15.0.orig.tar.xz: liblxqt-0.15.0/translations/liblxqt_sk_SK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialóg</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="75"/>
        <source>LXQt Power Manager Error</source>
        <translation>Chyba správcu napájania LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="75"/>
        <source>Hibernate failed.</source>
        <translation>Hibernácia sa nepodarila.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="154"/>
        <source>Notifications Fallback</source>
        <translation>Náhradné oznámenia</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="118"/>
        <source>Hibernate</source>
        <translation>Hibernovať</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="125"/>
        <source>Suspend</source>
        <translation>Úsporný režim</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="132"/>
        <source>Reboot</source>
        <translation>Reštartovať</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="139"/>
        <source>Shutdown</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="146"/>
        <source>Logout</source>
        <translation>Odhlásiť sa</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>LXQt Session Suspend</source>
        <translation>Úsporný režim relácie LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="159"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Skutočne chcete svoj počítač uviesť do úsporného režimu?&lt;p&gt;Uvedie počítač do stavu s nízkym odberom prúdu. Stav systému sa pri strate napájania nezachová.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>LXQt Session Hibernate</source>
        <translation>Hibernácia relácie LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="169"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Skutočne chcete svoj počítač hibernovať?&lt;p&gt;Uvedie počítač do stavu s nízkym odberom prúdu. Stav systému sa pri strate napájania zachová.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>LXQt Session Reboot</source>
        <translation>Reštart relácie LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="179"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Skutočne chcete svoj počítač reštartovať? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>LXQt Session Shutdown</source>
        <translation>Vypnutie relácie LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="189"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Skutočne chcete svoj počítač vypnúť? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="198"/>
        <source>LXQt Session Logout</source>
        <translation>Odhlásenie relácie LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="199"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Skutočne sa chcete odhlásiť z vášho počítača? Akákoľvek neuložená práca sa stratí...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="207"/>
        <location filename="../lxqtpowermanager.cpp" line="212"/>
        <source>LXQt Power Manager Error</source>
        <translation>Chyba správcu napájania LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="207"/>
        <source>Hibernate failed.</source>
        <translation>Hibernácia sa nepodarila.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="212"/>
        <source>Suspend failed.</source>
        <translation>Uvedenie do úsporného režimu sa nepodarilo.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="161"/>
        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
        <translation>Nepodarilo sa spustiť„%1“. Zaistite, aby bol nainštalovaný nástroj na zamykanie/šetrič  obrazovky, kompatibilný so špecifikáciou xdg-screensaver a bol aj spustený.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="165"/>
        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
        <translation>Nepodarilo sa spustiť „%1“.  Zaistite, aby bol nainštalovaný a spustený príslušný nástroj pre zamykanie / šetrič obrazovky.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="243"/>
        <source>Lock Screen</source>
        <translation>Zamknúť obrazovku</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Chyba šetriča obrazovky</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation>Vyberte si stránku na zobrazenie.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Chyba správcu napájania</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface je nepoužiteľné</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Chyba správcu napájania (volanie D-Bus)</translation>
    </message>
</context>
</TS>
